@@ -5,12 +5,13 @@ package Spreadsheet::SimpleExcel;
 use 5.006;
 use strict;
 use warnings;
+
 use Spreadsheet::WriteExcel;
 use IO::Scalar;
 use IO::File;
 use XML::Writer;
 
-our $VERSION     = '1.91';
+our $VERSION     = '1.92';
 our $errstr      = '';
 
 sub new{
@@ -621,8 +622,21 @@ sub sheets{
 }# end sheets
 
 1;
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+Spreadsheet::SimpleExcel - Create Excel files with Perl
+
+=head1 VERSION
+
+version 1.92
+
 =head1 SYNOPSIS
 
   use Spreadsheet::SimpleExcel;
@@ -721,7 +735,7 @@ This leads to more usability.
   
   #if a file > 7 MB should be created
   $excel = Spreadsheet::SimpleExcel->new(-big => 1);
-  
+
 If -big is set to true, Spreadsheet::WriteExcel::Big is required!
 
 =head2 add_worksheet
@@ -765,14 +779,14 @@ sort_data sorts the rows. All sorts for one worksheet are combined, so
 
   $excel->sort_data('Name of Worksheet',0,'DESC');
   $excel->sort_data('Name of Worksheet',1,'ASC');
-  
+
 will sort the column 0 first and then (within this sorted data) the
 column 1.
 
 =head2 reset_sort
 
   $excel->reset_sort('Name of Worksheet');
-  
+
 The data won't be sorted, the data are in original order instead.
 
 =head2 set_headers
@@ -817,9 +831,8 @@ The data will be printed into more worksheets, if the number of rows is greater
 
 =head2 output_to_XML
 
-  
   $excel2->output_to_XML('test.xml');
-  
+
 prints the data into a XML file.
 
 =head2 sheets
@@ -977,4 +990,16 @@ IO::File
 
 XML::Writer
 
+=head1 AUTHOR
+
+Renee Baecker <reneeb@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2015 by Renee Baecker.
+
+This is free software, licensed under:
+
+  The Artistic License 2.0 (GPL Compatible)
+
 =cut
